# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: coordinate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63oordinate.proto\x12\x0fprotocoordinate\"\xee\x01\n\nUpdateData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x31\n\x06\x63oords\x18\x02 \x03(\x0b\x32!.protocoordinate.UpdateData.Coord\x12;\n\x0bquaternions\x18\x03 \x03(\x0b\x32&.protocoordinate.UpdateData.Quaternion\x1a(\n\x05\x43oord\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x1a\x38\n\nQuaternion\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01w\x18\x04 \x01(\x02\x62\x06proto3')



_UPDATEDATA = DESCRIPTOR.message_types_by_name['UpdateData']
_UPDATEDATA_COORD = _UPDATEDATA.nested_types_by_name['Coord']
_UPDATEDATA_QUATERNION = _UPDATEDATA.nested_types_by_name['Quaternion']
UpdateData = _reflection.GeneratedProtocolMessageType('UpdateData', (_message.Message,), {

  'Coord' : _reflection.GeneratedProtocolMessageType('Coord', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEDATA_COORD,
    '__module__' : 'coordinate_pb2'
    # @@protoc_insertion_point(class_scope:protocoordinate.UpdateData.Coord)
    })
  ,

  'Quaternion' : _reflection.GeneratedProtocolMessageType('Quaternion', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEDATA_QUATERNION,
    '__module__' : 'coordinate_pb2'
    # @@protoc_insertion_point(class_scope:protocoordinate.UpdateData.Quaternion)
    })
  ,
  'DESCRIPTOR' : _UPDATEDATA,
  '__module__' : 'coordinate_pb2'
  # @@protoc_insertion_point(class_scope:protocoordinate.UpdateData)
  })
_sym_db.RegisterMessage(UpdateData)
_sym_db.RegisterMessage(UpdateData.Coord)
_sym_db.RegisterMessage(UpdateData.Quaternion)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _UPDATEDATA._serialized_start=38
  _UPDATEDATA._serialized_end=276
  _UPDATEDATA_COORD._serialized_start=178
  _UPDATEDATA_COORD._serialized_end=218
  _UPDATEDATA_QUATERNION._serialized_start=220
  _UPDATEDATA_QUATERNION._serialized_end=276
# @@protoc_insertion_point(module_scope)
