BLUE_E = "#1C758A"
BLUE_D = "#29ABCA"
BLUE_C = "#58C4DD"
BLUE_B = "#9CDCEB"
BLUE_A = "#C7E9F1"
TEAL_E = "#49A88F"
TEAL_D = "#55C1A7"
TEAL_C = "#5CD0B3"
TEAL_B = "#76DDC0"
TEAL_A = "#ACEAD7"
GREEN_E = "#699C52"
GREEN_D = "#77B05D"
GREEN_C = "#83C167"
GREEN_B = "#A6CF8C"
GREEN_A = "#C9E2AE"
YELLOW_E = "#E8C11C"
YELLOW_D = "#F4D345"
YELLOW_C = "#FFFF00"
YELLOW_B = "#FFEA94"
YELLOW_A = "#FFF1B6"
GOLD_E = "#C78D46"
GOLD_D = "#E1A158"
GOLD_C = "#F0AC5F"
GOLD_B = "#F9B775"
GOLD_A = "#F7C797"
RED_E = "#CF5044"
RED_D = "#E65A4C"
RED_C = "#FC6255"
RED_B = "#FF8080"
RED_A = "#F7A1A3"
MAROON_E = "#94424F"
MAROON_D = "#A24D61"
MAROON_C = "#C55F73"
MAROON_B = "#EC92AB"
MAROON_A = "#ECABC1"
PURPLE_E = "#644172"
PURPLE_D = "#715582"
PURPLE_C = "#9A72AC"
PURPLE_B = "#B189C6"
PURPLE_A = "#CAA3E8"
GREY_E = "#222222"
GREY_D = "#444444"
GREY_C = "#888888"
GREY_B = "#BBBBBB"
GREY_A = "#DDDDDD"
WHITE = "#FFFFFF"
BLACK = "#000000"
GREY_BROWN = "#736357"
DARK_BROWN = "#8B4513"
LIGHT_BROWN = "#CD853F"
PINK = "#D147BD"
LIGHT_PINK = "#DC75CD"
GREEN_SCREEN = "#00FF00"
ORANGE = "#FF862F"

# Abbreviated names for the "median" colors
BLUE = BLUE_C
TEAL = TEAL_C
GREEN = GREEN_C
YELLOW = YELLOW_C
GOLD = GOLD_C
RED = RED_C
MAROON = MAROON_C
PURPLE = PURPLE_C
GREY = GREY_C

# ---------------------------
red_lighter = "#FFEBEE"
red_light = "#EF9A9A"
red = "#EF5350"
red_dark = "#E53935"
red_darker = "#C62828"

pink_lighter = "#FCE4EC"
pink_light = "#F48FB1"
pink = "#EC407A"
pink_dark = "#D81B60"
pink_darker = "#AD1457"

purple_lighter = "#F3E5F5"
purple_light = "#CE93D8"
purple = "#AB47BC"
purple_dark = "#8E24AA"
purple_darker = "#6A1B9A"

deep_purple_lighter = "#EDE7F6"
deep_purple_light = "#B39DDB"
deep_purple = "#7E57C2"
deep_purple_dark = "#5E35B1"
deep_purple_darker = "#4527A0"

indigo_lighter = "#E8EAF6"
indigo_light = "#9FA8DA"
indigo = "#5C6BC0"
indigo_dark = "#3949AB"
indigo_darker = "#283593"

blue_lighter = "#E3F2FD"
blue_light = "#90CAF9"
blue = "#42A5F5"
blue_dark = "#1E88E5"
blue_darker = "#1565C0"

light_blue_lighter = "#E1F5FE"
light_blue_light = "#81D4FA"
light_blue = "#29B6F6"
light_blue_dark = "#039BE5"
light_blue_darker = "#0277BD"

cyan_lighter = "#E0F7FA"
cyan_light = "#80DEEA"
cyan = "#26C6DA"
cyan_dark = "#00ACC1"
cyan_darker = "#00838F"

teal_lighter = "#E0F2F1"
teal_light = "#80CBC4"
teal = "#26A69A"
teal_dark = "#00897B"
teal_darker = "#00695C"

green_lighter = "#E8F5E9"
green_light = "#A5D6A7"
green = "#66BB6A"
green_dark = "#43A047"
green_darker = "#2E7D32"

light_green_lighter = "#F1F8E9"
light_green_light = "#C5E1A5"
light_green = "#9CCC65"
light_green_dark = "#7CB342"
light_green_darker = "#558B2F"

lime_lighter = "#F9FBE7"
lime_light = "#E6EE9C"
lime = "#D4E157"
lime_dark = "#C0CA33"
lime_darker = "#9E9D24"

yellow_lighter = "#FFFDE7"
yellow_light = "#FFF59D"
yellow = "#FFEE58"
yellow_dark = "#FDD835"
yellow_darker = "#F9A825"

amber_lighter = "#FFF8E1"
amber_light = "#FFE082"
amber = "#FFCA28"
amber_dark = "#FFB300"
amber_darker = "#FF8F00"

orange_lighter = "#FFF3E0"
orange_light = "#FFCC80"
orange = "#FFA726"
orange_dark = "#FB8C00"
orange_darker = "#EF6C00"

salmon_lighter = "#FBE9E7"
salmon_light = "#FFAB91"
salmon = "#FF7043"
salmon_dark = "#F4511E"
salmon_darker = "#D84315"

brown_lighter = "#EFEBE9"
brown_light = "#BCAAA4"
brown = "#8D6E63"
brown_dark = "#6D4C41"
brown_darker = "#4E342E"

grey_lighter = "#FAFAFA"
grey_light = "#EEEEEE"
grey = "#BDBDBD"
grey_dark = "#757575"
grey_darker = "#424242"

blue_grey_lighter = "#ECEFF1"
blue_grey_light = "#B0BEC5"
blue_grey = "#78909C"
blue_grey_dark = "#546E7A"
blue_grey_darker = "#37474F"

black = "#000000"
white = "#FFFFFF"
