# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: trainstatus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11trainstatus.proto\x12\x0bprotostatus\"m\n\x0bTrainStatus\x12\x10\n\x08\x66inished\x18\x01 \x01(\x08\x12\x0c\n\x04step\x18\x02 \x01(\x05\x12\x0c\n\x04loss\x18\x03 \x01(\x02\x12\x10\n\x08progress\x18\x04 \x01(\x02\x12\x11\n\tcost_time\x18\x05 \x01(\x01\x12\x0b\n\x03msg\x18\x06 \x01(\t\"Q\n\x0cHttpResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12&\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x18.protostatus.TrainStatusb\x06proto3')



_TRAINSTATUS = DESCRIPTOR.message_types_by_name['TrainStatus']
_HTTPRESPONSE = DESCRIPTOR.message_types_by_name['HttpResponse']
TrainStatus = _reflection.GeneratedProtocolMessageType('TrainStatus', (_message.Message,), {
  'DESCRIPTOR' : _TRAINSTATUS,
  '__module__' : 'trainstatus_pb2'
  # @@protoc_insertion_point(class_scope:protostatus.TrainStatus)
  })
_sym_db.RegisterMessage(TrainStatus)

HttpResponse = _reflection.GeneratedProtocolMessageType('HttpResponse', (_message.Message,), {
  'DESCRIPTOR' : _HTTPRESPONSE,
  '__module__' : 'trainstatus_pb2'
  # @@protoc_insertion_point(class_scope:protostatus.HttpResponse)
  })
_sym_db.RegisterMessage(HttpResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRAINSTATUS._serialized_start=34
  _TRAINSTATUS._serialized_end=143
  _HTTPRESPONSE._serialized_start=145
  _HTTPRESPONSE._serialized_end=226
# @@protoc_insertion_point(module_scope)
