syntax = "proto3";

package protocoordinate;


message UpdateData {
  string name = 1;
  message Coord {
    float x = 1;
    float y = 2;
    float z = 3;
  }
  repeated Coord coords = 2;
  message Quaternion {
    float x = 1;
    float y = 2;
    float z = 3;
    float w = 4;
  }
  repeated Quaternion quaternions = 3;
}
