syntax = "proto3";

package protostatus;

message TrainStatus {
  bool finished = 1;
  int32 step = 2;
  float loss = 3;
  float progress = 4;
  double cost_time = 5;
  string msg = 6;
  // timestamp 好像是protobuf里面的一个默认属性，用它会无法正常赋值。
}


message HttpResponse {
  int32 code = 1;
  string msg = 2;
  TrainStatus data = 3;
}

//message TodoList {
//  int32 owner_id = 1;
//  string owner_name = 2;
//
//  message ListItems {
//    State state = 1;
//    string task = 2;
//    string due_date = 3;
//  }
//
//  repeated ListItems todos = 3;
//}